memento — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- model »

# memento

class `camelot.model.memento.` `BeforeDelete`(**kwargs)

  The state of the object before it is deleted

class `camelot.model.memento.` `BeforeUpdate`(**kwargs)

  The state of the object before an update took place

class `camelot.model.memento.` `Create`(**kwargs)

  Marks the creation of an object

class `camelot.model.memento.` `Memento`(**kwargs)

  Keeps information on the previous state of objects, to keep track of changes and enable restore to that previous state

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- model »

Comments
blog comments powered by Disqus